@@ -12,11 +12,11 @@ use crate::{
     error::Result,
     messages::Variant,
     routing::command::Command,
-    section::SectionAuthorityProvider,
+    section::ElderCandidates,
     Error,
 };
 use bls_dkg::key_gen::message::Message as DkgMessage;
-use sn_messaging::{DstLocation, MessageType};
+use sn_messaging::DstLocation;
 use std::{collections::BTreeSet, iter, net::SocketAddr, slice};
 use xor_name::XorName;
 
@@ -24,12 +24,12 @@ impl Core {
     pub(crate) fn handle_dkg_start(
         &mut self,
         dkg_key: DkgKey,
-        new_section_auth: SectionAuthorityProvider,
+        elder_candidates: ElderCandidates,
     ) -> Result<Vec<Command>> {
-        trace!("Received DkgStart for {}", new_section_auth);
+        trace!("Received DkgStart for {:?}", elder_candidates);
         self.dkg_voter
-            .start(&self.node.keypair, dkg_key, new_section_auth)
-            .into_commands(&self.node)
+            .start(&self.node.keypair, dkg_key, elder_candidates)
+            .into_commands(&self.node, *self.section_chain().last_key())
     }
 
     pub(crate) fn handle_dkg_message(
@@ -42,7 +42,7 @@ impl Core {
 
         self.dkg_voter
             .process_message(&self.node.keypair, &dkg_key, message)
-            .into_commands(&self.node)
+            .into_commands(&self.node, *self.section_chain().last_key())
     }
 
     pub(crate) fn handle_dkg_failure_observation(
@@ -53,7 +53,7 @@ impl Core {
     ) -> Result<Vec<Command>> {
         self.dkg_voter
             .process_failure(&dkg_key, non_participants, proof)
-            .into_commands(&self.node)
+            .into_commands(&self.node, *self.section_chain().last_key())
     }
 
     pub(crate) fn handle_dkg_failure_agreement(
@@ -69,13 +69,13 @@ impl Core {
             .peer;
 
         let generation = self.section.chain().main_branch_len() as u64;
-        let section_auth = self
+        let elder_candidates = self
             .section
             .promote_and_demote_elders(&self.node.name())
             .into_iter()
-            .find(|section_auth| proofs.verify(section_auth, generation));
-        let section_auth = if let Some(section_auth) = section_auth {
-            section_auth
+            .find(|elder_candidates| proofs.verify(elder_candidates, generation));
+        let elder_candidates = if let Some(elder_candidates) = elder_candidates {
+            elder_candidates
         } else {
             trace!("Ignore DKG failure agreement with invalid proofs or outdated participants",);
             return Ok(vec![]);
@@ -84,18 +84,18 @@ impl Core {
         if proofs.non_participants.is_empty() {
             // The DKG failure is a corrupted one due to lagging.
             trace!(
-                "Received DKG failure agreement - restarting: {}",
-                section_auth
+                "Received DKG failure agreement - restarting: {:?}",
+                elder_candidates
             );
 
-            self.send_dkg_start_to(section_auth, slice::from_ref(sender))
+            self.send_dkg_start_to(elder_candidates, slice::from_ref(sender))
         } else {
             // The DKG failure is regarding non_participants, i.e. potential unresponsive node.
             trace!(
                 "Received DKG failure agreement of non_participants {:?} , DKG generation({}) {:?}",
                 proofs.non_participants,
                 generation,
-                section_auth
+                elder_candidates
             );
             self.cast_offline_proposals(&proofs.non_participants)
         }
@@ -125,48 +125,15 @@ impl Core {
         }
     }
 
-    pub fn handle_connection_lost(&self, addr: SocketAddr) -> Option<Command> {
-        if let Some(peer) = self.section.find_joined_member_by_addr(&addr) {
-            debug!("Lost connection to {}", peer);
-        } else {
-            if let Some(end_user) = self.get_enduser_by_addr(&addr) {
-                debug!("Lost connection to client {:?}", end_user);
-            } else {
-                debug!("Lost connection to unknown peer {}", addr);
-            }
-            return None;
-        }
-
-        if !self.is_elder() {
-            return None;
-        }
-
-        // Try to send a "ping" message to probe the peer connection. If it succeeds, the
-        // connection loss was just temporary. Otherwise the peer is assumed lost and we will
-        // propose it offline.
-        Some(Command::SendMessage {
-            recipients: vec![addr],
-            delivery_group_size: 1,
-            message: MessageType::Ping,
-        })
-    }
-
-    pub fn handle_peer_lost(&self, addr: &SocketAddr) -> Result<Vec<Command>> {
-        let name = if let Some(peer) = self.section.find_joined_member_by_addr(addr) {
-            debug!("Lost known peer {}", peer);
-            *peer.name()
-        } else {
-            trace!("Lost unknown peer {}", addr);
-            return Ok(vec![]);
-        };
-
+    fn complain_connectivity(&self, name: XorName) -> Result<Vec<Command>> {
         if !self.is_elder() {
             // When self is not an elder, then the peer has to be an elder, and we shall complaint
             // the lost to other elders.
             let variant = Variant::ConnectivityComplaint(name);
             let recipients: Vec<_> = self
                 .section
-                .authority_provider()
+                .proven_authority_provider()
+                .value
                 .peers()
                 .filter(|peer| *peer.name() != name)
                 .collect();
@@ -188,6 +155,34 @@ impl Core {
         self.propose_offline(name)
     }
 
+    pub fn handle_connection_lost(&self, addr: SocketAddr) -> Result<Vec<Command>> {
+        let name = if let Some(peer) = self.section.find_joined_member_by_addr(&addr) {
+            debug!("Lost connection to known peer {}", peer);
+            *peer.name()
+        } else {
+            if let Some(end_user) = self.get_enduser_by_addr(&addr) {
+                debug!("Lost connection to client {:?}", end_user);
+            } else {
+                debug!("Lost connection to unknown peer {}", addr);
+            }
+            return Ok(vec![]);
+        };
+
+        self.complain_connectivity(name)
+    }
+
+    pub fn handle_peer_lost(&self, addr: &SocketAddr) -> Result<Vec<Command>> {
+        let name = if let Some(peer) = self.section.find_joined_member_by_addr(addr) {
+            debug!("Lost known peer {}", peer);
+            *peer.name()
+        } else {
+            trace!("Lost unknown peer {}", addr);
+            return Ok(vec![]);
+        };
+
+        self.complain_connectivity(name)
+    }
+
     pub fn propose_offline(&self, name: XorName) -> Result<Vec<Command>> {
         self.cast_offline_proposals(&iter::once(name).collect())
     }
