@@ -70,7 +70,7 @@ pub struct SectionAuthorityProvider {
     /// The section prefix. It matches all the members' names.
     pub prefix: Prefix,
     /// Public key of the section.
-    section_key: PublicKey,
+    pub section_key: PublicKey,
     // The section's complete set of elders as a map from their name to their socket address.
     elders: BTreeMap<XorName, (PublicKeyShare, SocketAddr)>,
 }
@@ -247,7 +247,7 @@ pub(crate) mod test_utils {
     pub(crate) fn gen_section_authority_provider(
         prefix: Prefix,
         count: usize,
-    ) -> (SectionAuthorityProvider, Vec<Node>) {
+    ) -> (SectionAuthorityProvider, Vec<Node>, bls::SecretKeySet) {
         let nodes = gen_sorted_nodes(&prefix, count, false);
         let elders = nodes
             .iter()
@@ -265,6 +265,6 @@ pub(crate) mod test_utils {
             secret_key_set.public_keys(),
         );
 
-        (section_auth, nodes)
+        (section_auth, nodes, secret_key_set)
     }
 }
